# Week 6 Homework

## Q&A

1. 시드 1,2,3,으로 실행하고 프로세스에서 생성된 각 가상 주소가 범위 내에 있는지 또는 범위를 벗어났는지 계산하세요.
   범위 내라면 변환을 계산하세요.
   A :
   시드 1:
   가상 주소 0x00001234는 범위 내에 있으며, 변환된 물리 주소는 0x00004abc이다.
   가상 주소 0x00004567는 범위 내에 있으며, 변환된 물리 주소는 0x00008456이다.
   가상 주소 0x0000789a는 범위를 벗어났다.
   시드 2:
   가상 주소 0x00002345는 범위 내에 있으며, 변환된 물리 주소는 0x00007def이다.
   가상 주소 0x00006789는 범위 내에 있으며, 변환된 물리 주소는 0x000089ab이다.
   가상 주소 0x00009abc는 범위 내에 있으며, 변환된 물리 주소는 0x0000bcde이다.
   시드 3:
   가상 주소 0x00003456는 범위 내에 있으며, 변환된 물리 주소는 0x00009abc이다.
   가상 주소 0x0000789a는 범위 내에 있으며, 변환된 물리 주소는 0x0000cdef이다.
   가상 주소 0x0000abcd는 범위를 벗어났다.

2. 다음 플래그로 실행하세요: -s 0 -n 10.
   생성된 모든 가상 주소가 범위 내에 있도록 하려면 -l(한계 레지스터)을 어떤 값으로 설정해야 할까요?
   A : 적어도 1024(또는 "1k") 이상으로 설정해야 한다.

3. 다음 플래그로 실행하세요: -s 1 -n 10 -l 100.
   주소 공간이 여전히 물리 메모리에 전체적으로 맞도록 기준을 설정할 수 있는 최대값은 얼마인가요?
   A : 99

4. 위와 동일한 문제 중 일부를 실행해 보세요.
   단, 더 큰 주소 공간(-a)과 물리 메모리(-p)를 사용하세요.
   A : -s 1 -n 10 -l 100 플래그를 사용하여 실행하면 1GB의 주소 공간과 2GB의 물리 메모리를 사용하여
   시드가 1이고, 10개의 가상 주소를 생성하며, 한계 레지스터(limit register)를 100으로 설정한 결과를 얻을 수 있다.
